@@ -1,5 +1,6 @@
 var annotated_dup =
 [
+    [ "AlgoCfg", "structAlgoCfg.html", "structAlgoCfg" ],
     [ "aom_active_map", "structaom__active__map.html", "structaom__active__map" ],
     [ "aom_codec_ctx", "structaom__codec__ctx.html", "structaom__codec__ctx" ],
     [ "aom_codec_cx_pkt", "structaom__codec__cx__pkt.html", "structaom__codec__cx__pkt" ],
@@ -36,14 +37,21 @@ var annotated_dup =
     [ "aom_svc_ref_frame_config", "structaom__svc__ref__frame__config.html", "structaom__svc__ref__frame__config" ],
     [ "aom_tile_data", "structaom__tile__data.html", "structaom__tile__data" ],
     [ "aom_tile_info", "structaom__tile__info.html", "structaom__tile__info" ],
+    [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
+    [ "AV1_COMP_DATA", "structAV1__COMP__DATA.html", "structAV1__COMP__DATA" ],
     [ "av1_ext_ref_frame", "structav1__ext__ref__frame.html", "structav1__ext__ref__frame" ],
+    [ "AV1_PRIMARY", "structAV1__PRIMARY.html", "structAV1__PRIMARY" ],
     [ "av1_ref_frame", "structav1__ref__frame.html", "structav1__ref__frame" ],
     [ "AV1Common", "structAV1Common.html", "structAV1Common" ],
     [ "Av1DecodeReturn", "structAv1DecodeReturn.html", "structAv1DecodeReturn" ],
+    [ "AV1EncoderConfig", "structAV1EncoderConfig.html", "structAV1EncoderConfig" ],
+    [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
+    [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
     [ "CB_COEFF_BUFFER", "structCB__COEFF__BUFFER.html", "structCB__COEFF__BUFFER" ],
     [ "CdefBlockInfo", "structCdefBlockInfo.html", "structCdefBlockInfo" ],
     [ "CdefInfo", "structCdefInfo.html", "structCdefInfo" ],
     [ "cfg_options", "structcfg__options.html", "structcfg__options" ],
+    [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
     [ "CoeffCosts", "structCoeffCosts.html", "structCoeffCosts" ],
     [ "ColorCount", "structColorCount.html", "structColorCount" ],
     [ "CommonContexts", "structCommonContexts.html", "structCommonContexts" ],
@@ -51,19 +59,33 @@ var annotated_dup =
     [ "CommonQuantParams", "structCommonQuantParams.html", "structCommonQuantParams" ],
     [ "CommonTileParams", "structCommonTileParams.html", "structCommonTileParams" ],
     [ "COMP_RD_STATS", "structCOMP__RD__STATS.html", "structCOMP__RD__STATS" ],
+    [ "CompoundTypeCfg", "structCompoundTypeCfg.html", "structCompoundTypeCfg" ],
     [ "CompoundTypeRdBuffers", "structCompoundTypeRdBuffers.html", "structCompoundTypeRdBuffers" ],
     [ "CYCLIC_REFRESH", "structCYCLIC__REFRESH.html", "structCYCLIC__REFRESH" ],
     [ "DecoderCodingBlock", "structDecoderCodingBlock.html", "structDecoderCodingBlock" ],
+    [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
+    [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
+    [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
+    [ "ExternalFlags", "structExternalFlags.html", "structExternalFlags" ],
+    [ "ExtRefreshFrameFlagsInfo", "structExtRefreshFrameFlagsInfo.html", "structExtRefreshFrameFlagsInfo" ],
     [ "FeatureFlags", "structFeatureFlags.html", "structFeatureFlags" ],
     [ "FIRST_PASS_SPEED_FEATURES", "structFIRST__PASS__SPEED__FEATURES.html", "structFIRST__PASS__SPEED__FEATURES" ],
     [ "FIRSTPASS_INFO", "structFIRSTPASS__INFO.html", "structFIRSTPASS__INFO" ],
     [ "FIRSTPASS_STATS", "structFIRSTPASS__STATS.html", "structFIRSTPASS__STATS" ],
+    [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
+    [ "FrameProbInfo", "structFrameProbInfo.html", "structFrameProbInfo" ],
     [ "GF_FRAME_STATS", "structGF__FRAME__STATS.html", null ],
     [ "GF_GROUP", "structGF__GROUP.html", null ],
     [ "GF_GROUP_STATS", "structGF__GROUP__STATS.html", null ],
+    [ "GlobalMotionInfo", "structGlobalMotionInfo.html", "structGlobalMotionInfo" ],
     [ "HIGH_LEVEL_SPEED_FEATURES", "structHIGH__LEVEL__SPEED__FEATURES.html", "structHIGH__LEVEL__SPEED__FEATURES" ],
+    [ "InitialDimensions", "structInitialDimensions.html", "structInitialDimensions" ],
+    [ "inter_modes_info", "structinter__modes__info.html", "structinter__modes__info" ],
+    [ "InterpSearchFlags", "structInterpSearchFlags.html", "structInterpSearchFlags" ],
     [ "IntraBCMVCosts", "structIntraBCMVCosts.html", "structIntraBCMVCosts" ],
+    [ "IntraModeCfg", "structIntraModeCfg.html", "structIntraModeCfg" ],
     [ "IntraModeSearchState", "structIntraModeSearchState.html", "structIntraModeSearchState" ],
+    [ "KeyFrameCfg", "structKeyFrameCfg.html", "structKeyFrameCfg" ],
     [ "LAYER_CONTEXT", "structLAYER__CONTEXT.html", "structLAYER__CONTEXT" ],
     [ "LV_MAP_COEFF_COST", "structLV__MAP__COEFF__COST.html", "structLV__MAP__COEFF__COST" ],
     [ "LV_MAP_EOB_COST", "structLV__MAP__EOB__COST.html", "structLV__MAP__EOB__COST" ],
@@ -75,31 +97,47 @@ var annotated_dup =
     [ "MB_MODE_INFO_EXT_FRAME", "structMB__MODE__INFO__EXT__FRAME.html", "structMB__MODE__INFO__EXT__FRAME" ],
     [ "MB_RD_INFO", "structMB__RD__INFO.html", "structMB__RD__INFO" ],
     [ "MB_RD_RECORD", "structMB__RD__RECORD.html", "structMB__RD__RECORD" ],
+    [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
     [ "ModeCosts", "structModeCosts.html", "structModeCosts" ],
     [ "motion_mode_candidate", "structmotion__mode__candidate.html", "structmotion__mode__candidate" ],
+    [ "MotionVectorSearchParams", "structMotionVectorSearchParams.html", "structMotionVectorSearchParams" ],
+    [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
     [ "MvCosts", "structMvCosts.html", "structMvCosts" ],
     [ "OBMCBuffer", "structOBMCBuffer.html", "structOBMCBuffer" ],
     [ "PALETTE_BUFFER", "structPALETTE__BUFFER.html", "structPALETTE__BUFFER" ],
+    [ "PartitionCfg", "structPartitionCfg.html", "structPartitionCfg" ],
     [ "PartitionSearchInfo", "structPartitionSearchInfo.html", "structPartitionSearchInfo" ],
     [ "PRIMARY_RATE_CONTROL", "structPRIMARY__RATE__CONTROL.html", "structPRIMARY__RATE__CONTROL" ],
+    [ "PrimaryMultiThreadInfo", "structPrimaryMultiThreadInfo.html", "structPrimaryMultiThreadInfo" ],
     [ "PruneInfoFromTpl", "structPruneInfoFromTpl.html", "structPruneInfoFromTpl" ],
     [ "RATE_CONTROL", "structRATE__CONTROL.html", "structRATE__CONTROL" ],
+    [ "RateControlCfg", "structRateControlCfg.html", "structRateControlCfg" ],
+    [ "RefFrameDistanceInfo", "structRefFrameDistanceInfo.html", "structRefFrameDistanceInfo" ],
+    [ "RefreshFrameInfo", "structRefreshFrameInfo.html", "structRefreshFrameInfo" ],
+    [ "ResizeCfg", "structResizeCfg.html", "structResizeCfg" ],
+    [ "ResizePendingParams", "structResizePendingParams.html", "structResizePendingParams" ],
     [ "RestorationInfo", "structRestorationInfo.html", "structRestorationInfo" ],
     [ "RestorationStripeBoundaries", "structRestorationStripeBoundaries.html", "structRestorationStripeBoundaries" ],
     [ "RestorationUnitInfo", "structRestorationUnitInfo.html", "structRestorationUnitInfo" ],
+    [ "RestoreStateBuffers", "structRestoreStateBuffers.html", "structRestoreStateBuffers" ],
     [ "SgrprojInfo", "structSgrprojInfo.html", "structSgrprojInfo" ],
     [ "SPEED_FEATURES", "structSPEED__FEATURES.html", "structSPEED__FEATURES" ],
     [ "SuperBlockEnc", "structSuperBlockEnc.html", "structSuperBlockEnc" ],
+    [ "SuperResCfg", "structSuperResCfg.html", "structSuperResCfg" ],
     [ "SVC", "structSVC.html", "structSVC" ],
     [ "TEMPORAL_FILTER_INFO", "structTEMPORAL__FILTER__INFO.html", "structTEMPORAL__FILTER__INFO" ],
     [ "TemporalFilterCtx", "structTemporalFilterCtx.html", "structTemporalFilterCtx" ],
+    [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
     [ "TplParams", "structTplParams.html", "structTplParams" ],
     [ "TWO_PASS", "structTWO__PASS.html", null ],
     [ "TWO_PASS_FRAME", "structTWO__PASS__FRAME.html", null ],
     [ "TxfmSearchInfo", "structTxfmSearchInfo.html", "structTxfmSearchInfo" ],
     [ "TxfmSearchParams", "structTxfmSearchParams.html", "structTxfmSearchParams" ],
+    [ "TxfmSizeTypeCfg", "structTxfmSizeTypeCfg.html", "structTxfmSizeTypeCfg" ],
+    [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
     [ "WARP_SAMPLE_INFO", "structWARP__SAMPLE__INFO.html", "structWARP__SAMPLE__INFO" ],
     [ "WienerInfo", "structWienerInfo.html", "structWienerInfo" ],
+    [ "WinnerModeParams", "structWinnerModeParams.html", "structWinnerModeParams" ],
     [ "WinnerModeStats", "structWinnerModeStats.html", "structWinnerModeStats" ],
     [ "yv12_buffer_config", "structyv12__buffer__config.html", null ]
 ];
\ No newline at end of file
