@@ -25,8 +25,6 @@ var block_8h =
     [ "macroblock", "structmacroblock.html", "structmacroblock" ],
     [ "MIN_TPL_BSIZE_1D", "block_8h.html#ae0a195ea38f0a04ad9a9d6d7ed5bb754", null ],
     [ "MAX_TPL_BLK_IN_SB", "block_8h.html#a73de00e232811ea3f0290dcc425f86d5", null ],
-    [ "MAX_WINNER_MODE_COUNT_INTRA", "block_8h.html#ab657b1844dfce1e763e658761bb0952c", null ],
-    [ "MAX_WINNER_MODE_COUNT_INTER", "block_8h.html#a602ec0e36e0a86c78c15fe547c275e1f", null ],
     [ "RD_RECORD_BUFFER_LEN", "block_8h.html#a8c18014b69f341bf169c4a5656ee2978", null ],
     [ "MAX_TX_TYPE_PROB", "block_8h.html#a98e449b5753918529e949cfa37abd5a3", null ],
     [ "MAX_COMP_RD_STATS", "block_8h.html#a6e06ec17c5b54de9fd8d829fb2a305b7", null ],
