@@ -1,5 +1,24 @@
 var NAVTREEINDEX1 =
 {
+"encoder_guide.html#architecture_enc_intra_modes":[8,10],
+"encoder_guide.html#architecture_enc_kf_groups":[8,7,4],
+"encoder_guide.html#architecture_enc_partitions":[8,9],
+"encoder_guide.html#architecture_enc_rate_ctrl":[8,6],
+"encoder_guide.html#architecture_enc_rate_ctrl_data":[8,6,0],
+"encoder_guide.html#architecture_enc_rate_ctrl_options":[8,6,1],
+"encoder_guide.html#architecture_enc_rc_loop":[8,6,3],
+"encoder_guide.html#architecture_enc_speed_quality":[8,4],
+"encoder_guide.html#architecture_enc_src_proc":[8,5],
+"encoder_guide.html#architecture_enc_tpl":[8,8],
+"encoder_guide.html#architecture_enc_tpl_algoritms":[8,8,1],
+"encoder_guide.html#architecture_enc_tpl_config":[8,8,0],
+"encoder_guide.html#architecture_enc_tpl_keyfun":[8,8,2],
+"encoder_guide.html#architecture_enc_tx_search":[8,12],
+"encoder_guide.html#architecture_enc_use_cases":[8,3],
+"encoder_guide.html#architecture_enc_vbr":[8,6,2],
+"encoder_guide.html#architecture_entropy":[8,14],
+"encoder_guide.html#architecture_entropy_aritmetic":[8,14,0],
+"encoder_guide.html#architecture_entropy_coef":[8,14,1],
 "encoder_guide.html#architecture_entropy_coef_coding":[8,14,1,0,1],
 "encoder_guide.html#architecture_entropy_coef_context":[8,14,1,0,2],
 "encoder_guide.html#architecture_entropy_coef_cost":[8,14,1,1,0],
@@ -61,8 +80,8 @@ var NAVTREEINDEX1 =
 "functions_t.html":[13,1,0,19],
 "functions_u.html":[13,1,0,20],
 "functions_v.html":[13,1,0,21],
-"functions_vars.html":[13,1,1],
 "functions_vars.html":[13,1,1,0],
+"functions_vars.html":[13,1,1],
 "functions_vars_b.html":[13,1,1,1],
 "functions_vars_c.html":[13,1,1,2],
 "functions_vars_d.html":[13,1,1,3],
@@ -103,37 +122,42 @@ var NAVTREEINDEX1 =
 "globals_eval_c.html":[14,1,5,1],
 "globals_eval_e.html":[14,1,5,2],
 "globals_eval_i.html":[14,1,5,3],
-"globals_eval_p.html":[14,1,5,4],
-"globals_eval_q.html":[14,1,5,5],
-"globals_eval_r.html":[14,1,5,6],
-"globals_eval_s.html":[14,1,5,7],
-"globals_eval_t.html":[14,1,5,8],
+"globals_eval_l.html":[14,1,5,4],
+"globals_eval_n.html":[14,1,5,5],
+"globals_eval_p.html":[14,1,5,6],
+"globals_eval_q.html":[14,1,5,7],
+"globals_eval_r.html":[14,1,5,8],
+"globals_eval_s.html":[14,1,5,9],
+"globals_eval_t.html":[14,1,5,10],
 "globals_f.html":[14,1,0,3],
 "globals_func.html":[14,1,1],
 "globals_h.html":[14,1,0,4],
 "globals_i.html":[14,1,0,5],
-"globals_m.html":[14,1,0,6],
-"globals_o.html":[14,1,0,7],
-"globals_p.html":[14,1,0,8],
-"globals_q.html":[14,1,0,9],
-"globals_r.html":[14,1,0,10],
-"globals_s.html":[14,1,0,11],
-"globals_t.html":[14,1,0,12],
+"globals_l.html":[14,1,0,6],
+"globals_m.html":[14,1,0,7],
+"globals_n.html":[14,1,0,8],
+"globals_o.html":[14,1,0,9],
+"globals_p.html":[14,1,0,10],
+"globals_q.html":[14,1,0,11],
+"globals_r.html":[14,1,0,12],
+"globals_s.html":[14,1,0,13],
+"globals_t.html":[14,1,0,14],
 "globals_type.html":[14,1,3],
 "globals_vars.html":[14,1,2],
 "gop__structure_8h_source.html":[14,0,2,2,7],
 "group__SVC.html":[12,2,10],
-"group__SVC.html#ga2794fc40366548624954f66b967e8632":[12,2,10,11],
-"group__SVC.html#ga5dd7109b02e80cc7d843c94ae7c47e58":[12,2,10,5],
-"group__SVC.html#ga5f92b5ac15dcde4004d6f35586d4773b":[12,2,10,9],
-"group__SVC.html#ga653e04e3b1fe8ab04c663673e45f3a16":[12,2,10,6],
-"group__SVC.html#ga814c2aa58e2ca79dedfd0d9872316586":[12,2,10,7],
+"group__SVC.html#ga2794fc40366548624954f66b967e8632":[12,2,10,12],
+"group__SVC.html#ga5dd7109b02e80cc7d843c94ae7c47e58":[12,2,10,6],
+"group__SVC.html#ga5f92b5ac15dcde4004d6f35586d4773b":[12,2,10,10],
+"group__SVC.html#ga653e04e3b1fe8ab04c663673e45f3a16":[12,2,10,7],
+"group__SVC.html#ga814c2aa58e2ca79dedfd0d9872316586":[12,2,10,8],
+"group__SVC.html#ga851225444c51cbd64e23e6aac4086d46":[12,2,10,4],
 "group__SVC.html#ga8fd7af0cfb7a8a1031a11e391ce56b7b":[12,2,10,3],
 "group__SVC.html#gab71c263f4405fb913e3936da9bbd4f0c":[12,2,10,2],
-"group__SVC.html#gac3591bba20df432db53410504e3cbf42":[12,2,10,8],
-"group__SVC.html#gaf1d134bde262a8dde127bdd6b97a9d24":[12,2,10,10],
-"group__SVC.html#gaf592ef7e4ef34c2b94806e5c9d65b19c":[12,2,10,12],
-"group__SVC.html#gaf68d8ebe20cd4f5d244e1cfd57517971":[12,2,10,4],
+"group__SVC.html#gac3591bba20df432db53410504e3cbf42":[12,2,10,9],
+"group__SVC.html#gaf1d134bde262a8dde127bdd6b97a9d24":[12,2,10,11],
+"group__SVC.html#gaf592ef7e4ef34c2b94806e5c9d65b19c":[12,2,10,13],
+"group__SVC.html#gaf68d8ebe20cd4f5d244e1cfd57517971":[12,2,10,5],
 "group__aom.html":[12,1,0],
 "group__aom.html#ga48948a6e11f6b314f66a3387aee9d5df":[12,1,0,4],
 "group__aom.html#ga9421a1fa78c0d9587ae5aa6c1cb3d659":[12,1,0,5],
@@ -225,29 +249,5 @@ var NAVTREEINDEX1 =
 "group__aom__encoder.html#ga6ee5804fef84710679f46bb77895aa90":[12,1,0,0,28],
 "group__aom__encoder.html#ga7543b396ff2eef24d90b8edd094a9148":[12,1,0,0,79],
 "group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38":[12,1,0,0,36],
-"group__aom__encoder.html#ga77adf3b7884b3619a4c5cbc236fe9de5":[12,1,0,0,88],
-"group__aom__encoder.html#ga790f05ad7832f2614a13fd60bd3430fe":[12,1,0,0,59],
-"group__aom__encoder.html#ga7a55a46970c074b761319c5c46d87b6e":[12,1,0,0,38],
-"group__aom__encoder.html#ga801f5eb2cb93da19a2f347ae7a44166a":[12,1,0,0,84],
-"group__aom__encoder.html#ga834aa2b6069db7cc53b0a6e6b23ab557":[12,1,0,0,74],
-"group__aom__encoder.html#ga88539c1f9e72d6ab6f8802ff265539dd":[12,1,0,0,52],
-"group__aom__encoder.html#ga8a09d2e568a6727f6dcfa189dcb64dc0":[12,1,0,0,66],
-"group__aom__encoder.html#ga8ac829090566737c469a7147207e8855":[12,1,0,0,50],
-"group__aom__encoder.html#ga8f20643dbd528f92fc0ecd96d9726d09":[12,1,0,0,71],
-"group__aom__encoder.html#ga900ebe22eaa0f9296c4a876316fd4d82":[12,1,0,0,69],
-"group__aom__encoder.html#ga98480541d93f77481d44dfb0896fcdc5":[12,1,0,0,44],
-"group__aom__encoder.html#ga9e2f989737d63ddf4e987a525d186a46":[12,1,0,0,35],
-"group__aom__encoder.html#ga9f3d7cfaa6290b207c0ce360ed63ae45":[12,1,0,0,48],
-"group__aom__encoder.html#gaa4bc8ae2b977b73f0ef57ba428ca1d2c":[12,1,0,0,33],
-"group__aom__encoder.html#gaa81cc31f95fd463f51a158050d267a36":[12,1,0,0,39],
-"group__aom__encoder.html#gaaef6fe76991abf87edd2f296eee999f8":[12,1,0,0,34],
-"group__aom__encoder.html#gaafd352cc596fab5388558950f8bbe739":[12,1,0,0,86],
-"group__aom__encoder.html#gab64a195ea67269e704df30e39a22ca42":[12,1,0,0,72],
-"group__aom__encoder.html#gab9478e27301dfb5581f8bdf9efb40f3e":[12,1,0,0,63],
-"group__aom__encoder.html#gac18e4b6e5fd6cb617a2674cf3de3f57e":[12,1,0,0,70],
-"group__aom__encoder.html#gac5a69f04b0bc88f755587a1da815d754":[12,1,0,0,41],
-"group__aom__encoder.html#gaca3421fd8424ed3ab48704748a12c9d1":[12,1,0,0,51],
-"group__aom__encoder.html#gacd5a13523326346771b2cf343cea96be":[12,1,0,0,75],
-"group__aom__encoder.html#gacfd479b87a0dc8cb0602268f9dca37ce":[12,1,0,0,60],
-"group__aom__encoder.html#gad04799a74215e1b9609f7ccd1766f8c9":[12,1,0,0,37]
+"group__aom__encoder.html#ga77adf3b7884b3619a4c5cbc236fe9de5":[12,1,0,0,88]
 };
