@@ -1,6 +1,32 @@
 var NAVTREEINDEX3 =
 {
-"group__cyclic__refresh.html#gafb17f1befe613fac6ceebb9b5b24ebd8":[12,2,9,3],
+"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a5abd24080a18d4f7e33217d93a73e968":[12,0,34,0],
+"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61aaabb4d9ad771b2fa177ff6fb5437b179":[12,0,34,2],
+"group__codecs.html":[12,1],
+"group__coefficient__coding.html":[12,2,5],
+"group__coefficient__coding.html#ga0076c2c06ae74fd7b00193d4aa2f1d46":[12,2,5,4],
+"group__coefficient__coding.html#ga1618c5468421234169f9b285bc70a59c":[12,2,5,13],
+"group__coefficient__coding.html#ga1f9147fbeb6681f1f2ffd99806c93526":[12,2,5,0],
+"group__coefficient__coding.html#ga225614c4ff1863904ee8a80e0d971cc4":[12,2,5,12],
+"group__coefficient__coding.html#ga24b28c5ec4bc705cc58a7655c8218e4d":[12,2,5,3],
+"group__coefficient__coding.html#ga2afb7e8b3781bec12c44908fc5eaff51":[12,2,5,2],
+"group__coefficient__coding.html#ga4bd51731afdd25275377807e067c9d12":[12,2,5,7],
+"group__coefficient__coding.html#ga50e1752ad80721912848f6087b7b1025":[12,2,5,5],
+"group__coefficient__coding.html#ga8bc502fea9846765fba7de6a8fd90279":[12,2,5,10],
+"group__coefficient__coding.html#ga99f06925f4adb19ffb5fcbc12745ab94":[12,2,5,11],
+"group__coefficient__coding.html#gab27521d24faa93e58a1ce487b1e8f626":[12,2,5,9],
+"group__coefficient__coding.html#gabb195b5ee31923fbd15fe4caaf466278":[12,2,5,1],
+"group__coefficient__coding.html#gad0c28d34dad6636237409bf2e1ee2014":[12,2,5,6],
+"group__coefficient__coding.html#gae0b8d3b37b0b43f1cfbd0f91cc4cc991":[12,2,5,8],
+"group__cyclic__refresh.html":[12,2,9],
+"group__cyclic__refresh.html#ga1e8e194fae8285692651fb856b49c185":[12,2,9,2],
+"group__cyclic__refresh.html#ga320b85772ac318291cc2bb14c249a1d8":[12,2,9,8],
+"group__cyclic__refresh.html#ga35ec71ccbbc64bcb31ed02229dfe9ae0":[12,2,9,4],
+"group__cyclic__refresh.html#ga3703e9a518f8f17e7b6b601a456dbde8":[12,2,9,1],
+"group__cyclic__refresh.html#ga6a9f795a98618a842fece25ef85f20cf":[12,2,9,3],
+"group__cyclic__refresh.html#gaa4acc60c7ec3fc459b5ce65920493823":[12,2,9,6],
+"group__cyclic__refresh.html#gab14ed0139e8ebd0177d8a4b9c1e273ce":[12,2,9,7],
+"group__cyclic__refresh.html#gab63536700b85e6560aed37f0b8afbcaf":[12,2,9,5],
 "group__cyclic__refresh.html#gafc1304a44c092d497a6cbbbaef92d1b9":[12,2,9,9],
 "group__decoder.html":[12,0,0],
 "group__decoder.html#ga23378c7ca8c361c097181aaaa2a5a734":[12,0,0,4],
@@ -78,22 +104,25 @@ var NAVTREEINDEX3 =
 "group__high__level__algo.html#ga0d530935e53f27ab76f0dada5a8b94b6":[12,2,0,16],
 "group__high__level__algo.html#ga0f59145ac0765033ee267ba203baed23":[12,2,0,12],
 "group__high__level__algo.html#ga29eed659e71f7b8e1aef31d8cb4bb9ea":[12,2,0,7],
+"group__high__level__algo.html#ga4017ec9e9cfd7bd461775266c80ff46d":[12,2,0,18],
+"group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37":[12,2,0,17],
 "group__high__level__algo.html#ga6b56870ab498cf798e1e16c38b4c197c":[12,2,0,8],
 "group__high__level__algo.html#ga7c707e2dc0a45e03ee9cd81f97552a0b":[12,2,0,9],
-"group__high__level__algo.html#ga7d1e860d1b77466051044c86dff13528":[12,2,0,11],
 "group__high__level__algo.html#ga87fccf520455ff9a41aa381b40b8862c":[12,2,0,13],
 "group__high__level__algo.html#ga9f2d93e66cde2eccb5f4dcd5d08c6d6a":[12,2,0,10],
 "group__high__level__algo.html#gac237dcb6e36d4dbff616e618ab4985a6":[12,2,0,14],
+"group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7":[12,2,0,19],
 "group__high__level__algo.html#gaec07a41d07f7cd08a258531cd8935c68":[12,2,0,15],
+"group__high__level__algo.html#gafca3ffd2882283c32dbb6f958a7c6e04":[12,2,0,11],
 "group__in__loop__cdef.html":[12,2,7],
+"group__in__loop__cdef.html#ga930c781dbd8d604fe8b4a3e76b075b8e":[12,2,7,1],
 "group__in__loop__cdef.html#ga954983bebf726d3c6a4977410dfc607f":[12,2,7,0],
-"group__in__loop__cdef.html#gabc3885599bde5981a79222e22b34dc80":[12,2,7,1],
 "group__in__loop__filter.html":[12,2,6],
 "group__in__loop__filter.html#ga380290fdff07ec7b4ad5d768c676176d":[12,2,6,0],
 "group__in__loop__restoration.html":[12,2,8],
 "group__in__loop__restoration.html#ga476124fb6e4f853a2705bb32a56432b2":[12,2,8,2],
 "group__in__loop__restoration.html#ga65482f59379cfb1236341521d4c99391":[12,2,8,1],
-"group__in__loop__restoration.html#ga85b282be95f7e73f18532a32c1d3cb06":[12,2,8,0],
+"group__in__loop__restoration.html#gab2102fa7b1b4fff4ba450c9713858cef":[12,2,8,0],
 "group__inter__mode__search.html":[12,2,3],
 "group__inter__mode__search.html#ga28ac2b8a29decf12e7f601075093209b":[12,2,3,4],
 "group__inter__mode__search.html#ga43b5823e9da166d41854f95ae1d87f5f":[12,2,3,3],
@@ -103,19 +132,19 @@ var NAVTREEINDEX3 =
 "group__inter__mode__search.html#gae1aedf721583700393db3502d6042350":[12,2,3,1],
 "group__inter__mode__search.html#gaef5164626f2fbec0be2c3094fb13b079":[12,2,3,5],
 "group__intra__mode__search.html":[12,2,2],
-"group__intra__mode__search.html#ga1f6f374f792d71c79d53949a185799d6":[12,2,2,18],
-"group__intra__mode__search.html#ga3a03891b3b454db9c4446f779d3bfa44":[12,2,2,9],
-"group__intra__mode__search.html#ga3dba7f81ba3f8ca55df5dc98f871f8e8":[12,2,2,12],
+"group__intra__mode__search.html#ga14876528b3b166a692c1c1c15001c6f0":[12,2,2,9],
 "group__intra__mode__search.html#ga46ac7127978a1310a85adc9a1e878668":[12,2,2,4],
 "group__intra__mode__search.html#ga520ae1e2beb80b7b069e71dc0c881f6f":[12,2,2,5],
+"group__intra__mode__search.html#ga53cc7226efbd31e4f63d2db3bc60a991":[12,2,2,7],
+"group__intra__mode__search.html#ga53d65bd62b592d5471f9b8a4d4edf5cb":[12,2,2,18],
 "group__intra__mode__search.html#ga54a3be2975508906034952fea34e6556":[12,2,2,15],
 "group__intra__mode__search.html#ga592fed21d73cb4034c0eca70da7fae1c":[12,2,2,14],
 "group__intra__mode__search.html#ga5c63552bf8f204e19cae7adfc6185b3a":[12,2,2,13],
-"group__intra__mode__search.html#ga5d1279f833651cdbb96966d83076f563":[12,2,2,7],
-"group__intra__mode__search.html#ga868a4e2cc95d1134e057ebf3a320c07a":[12,2,2,8],
+"group__intra__mode__search.html#ga5fea046b0c9d683cec6817dca408b352":[12,2,2,8],
 "group__intra__mode__search.html#ga888b8c7618a6df45a38e48f52e020ced":[12,2,2,17],
 "group__intra__mode__search.html#ga8f5e96e865ec83e37cb62fe69882a259":[12,2,2,10],
 "group__intra__mode__search.html#gab0adec0117540b9786dd57688c8020b0":[12,2,2,11],
+"group__intra__mode__search.html#gab0cdb0a30e1cdb6d089dcb2bb9edced7":[12,2,2,12],
 "group__intra__mode__search.html#gac3bbfdab84b3600422e2d77cc7dd62e8":[12,2,2,6],
 "group__intra__mode__search.html#gae234e4fbb4d2abad145f4353595fd8e6":[12,2,2,2],
 "group__intra__mode__search.html#gaf72915b72e91552643b40aa506ed426d":[12,2,2,3],
@@ -123,40 +152,43 @@ var NAVTREEINDEX3 =
 "group__look__ahead__buffer.html":[12,2,0,5],
 "group__nonrd__mode__search.html":[12,2,12],
 "group__nonrd__mode__search.html#ga328360c35ea0f27804a7e649ea5d422a":[12,2,12,4],
-"group__nonrd__mode__search.html#ga3a61b19639ac3efe9d0ff860b0bc96fb":[12,2,12,8],
-"group__nonrd__mode__search.html#ga511634680c0fb42d578b7949592d7ff8":[12,2,12,7],
-"group__nonrd__mode__search.html#ga7c3da29aa38fb05510d2499aee49ea70":[12,2,12,5],
+"group__nonrd__mode__search.html#ga3d33f0dfb15ff25d44a77516d61225d5":[12,2,12,5],
+"group__nonrd__mode__search.html#ga51dad2928c18bada8ded395668e3e935":[12,2,12,6],
 "group__nonrd__mode__search.html#gaa980b8229e59638e72d3445c3014cc79":[12,2,12,3],
+"group__nonrd__mode__search.html#gab834528ee6b9df08ee430581dad845da":[12,2,12,8],
 "group__nonrd__mode__search.html#gabaa9801201975d4288732eea8ef24851":[12,2,12,1],
 "group__nonrd__mode__search.html#gac73009a89c66c664750636626bc9452f":[12,2,12,2],
-"group__nonrd__mode__search.html#gac99f0993e853863177432a90cd83d5c7":[12,2,12,6],
+"group__nonrd__mode__search.html#gac99f0993e853863177432a90cd83d5c7":[12,2,12,7],
 "group__nonrd__mode__search.html#gafa44920244086ceee2883b80341c61d8":[12,2,12,0],
+"group__nonrd__mode__search.html#gafa68dbad4c9b44f853869749dd4ac013":[12,2,12,9],
 "group__palette__mode__search.html":[12,2,2,0],
-"group__palette__mode__search.html#ga0865030d0ffa042390ab2472e77f957d":[12,2,2,0,0],
+"group__palette__mode__search.html#ga147640a97b720f170176589f40052988":[12,2,2,0,9],
 "group__palette__mode__search.html#ga2cb9b1049cdc0060881083633ccee68f":[12,2,2,0,5],
 "group__palette__mode__search.html#ga3ef821348e6d88fc171a8af5d070a5ca":[12,2,2,0,3],
-"group__palette__mode__search.html#ga499204b04894f62208ecd7481fd837ac":[12,2,2,0,2],
-"group__palette__mode__search.html#ga4c2ba8b9ea7370f75f364481f0aec9a3":[12,2,2,0,1],
-"group__palette__mode__search.html#ga5a3719d514a1fc927159d4af8f98f11c":[12,2,2,0,7],
-"group__palette__mode__search.html#ga61d1268829ad46968d16161466ac3b76":[12,2,2,0,9],
-"group__palette__mode__search.html#ga79e23cb5955092ba04bee379e97df918":[12,2,2,0,8],
+"group__palette__mode__search.html#ga80f626349d4e58b164c7a57fefbcd83a":[12,2,2,0,8],
 "group__palette__mode__search.html#gaa6a39d9de82e0e5cd963473067334e17":[12,2,2,0,4],
+"group__palette__mode__search.html#gab303c97534cd091ada24b034289a21a4":[12,2,2,0,1],
+"group__palette__mode__search.html#gab8813de381028651eb53216b019430b9":[12,2,2,0,0],
 "group__palette__mode__search.html#gab9bf846634be27493a882c390fd7bc55":[12,2,2,0,6],
+"group__palette__mode__search.html#gaf6eaf3e49c594d167c458e7cced8bd50":[12,2,2,0,2],
+"group__palette__mode__search.html#gafab99f1ec2dfb2267b7396f474ecfaf0":[12,2,2,0,7],
 "group__partition__search.html":[12,2,1],
-"group__partition__search.html#ga0664c147707f2d528d53cc09a7f41e20":[12,2,1,7],
-"group__partition__search.html#ga0940fd8dd7d0e3fddb48cdec3426e03f":[12,2,1,2],
-"group__partition__search.html#ga0d32a492481d81049254d362c3046d41":[12,2,1,3],
-"group__partition__search.html#ga2814000c23d084a5383f7c3669a40ec9":[12,2,1,6],
-"group__partition__search.html#ga73c2560dd156bd6a45160560ebfb16be":[12,2,1,9],
-"group__partition__search.html#ga825d23c65039a06658b783f641e4a369":[12,2,1,4],
-"group__partition__search.html#ga858f2a8955459b256a13fca734fc0948":[12,2,1,12],
-"group__partition__search.html#gab6ca7ecb046b0c7075bd7f3ca164b62a":[12,2,1,10],
-"group__partition__search.html#gac6ea78cef9b97053a93796b938d2a5a5":[12,2,1,13],
-"group__partition__search.html#gac96008483cc973bc1103cf990f7bbbee":[12,2,1,5],
+"group__partition__search.html#ga0664c147707f2d528d53cc09a7f41e20":[12,2,1,9],
+"group__partition__search.html#ga0d32a492481d81049254d362c3046d41":[12,2,1,5],
+"group__partition__search.html#ga2814000c23d084a5383f7c3669a40ec9":[12,2,1,8],
+"group__partition__search.html#ga3081716bcbb4f553c66d3cccfa7821b9":[12,2,1,2],
+"group__partition__search.html#ga73c2560dd156bd6a45160560ebfb16be":[12,2,1,11],
+"group__partition__search.html#ga825d23c65039a06658b783f641e4a369":[12,2,1,6],
+"group__partition__search.html#ga858f2a8955459b256a13fca734fc0948":[12,2,1,14],
+"group__partition__search.html#gab6ca7ecb046b0c7075bd7f3ca164b62a":[12,2,1,12],
+"group__partition__search.html#gac6ea78cef9b97053a93796b938d2a5a5":[12,2,1,15],
+"group__partition__search.html#gac96008483cc973bc1103cf990f7bbbee":[12,2,1,7],
 "group__partition__search.html#gacd50475d70739c9fa890e05d540cbca0":[12,2,1,0],
-"group__partition__search.html#gace5a349e10791d33edaaabf1fea7a839":[12,2,1,8],
+"group__partition__search.html#gacdef41ca81bd0793171a1a2b2fd07300":[12,2,1,4],
+"group__partition__search.html#gace5a349e10791d33edaaabf1fea7a839":[12,2,1,10],
 "group__partition__search.html#gacf0e64a22f62c95a3f8512f1cf0ec716":[12,2,1,1],
-"group__partition__search.html#gad9561a1da5a2377a8fa76435c8facef2":[12,2,1,11],
+"group__partition__search.html#gad9561a1da5a2377a8fa76435c8facef2":[12,2,1,13],
+"group__partition__search.html#gae25f4a644301f19a32106425997965c6":[12,2,1,3],
 "group__rate__control.html":[12,2,0,2],
 "group__rate__control.html#ga05ee091c593e5672c6be2d0bdd89d1cb":[12,2,0,2,4],
 "group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45":[12,2,0,2,39],
@@ -172,8 +204,8 @@ var NAVTREEINDEX3 =
 "group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2":[12,2,0,2,27],
 "group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993":[12,2,0,2,36],
 "group__rate__control.html#ga50283a647b83308a9a7c02b74a980ac1":[12,2,0,2,12],
+"group__rate__control.html#ga5aa5d85250b9dd9951113b4c7053dd43":[12,2,0,2,35],
 "group__rate__control.html#ga653667e5cc76259acc233c1986546599":[12,2,0,2,33],
-"group__rate__control.html#ga671ccd88dfed2d5be8f6c586910ab89e":[12,2,0,2,24],
 "group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae":[12,2,0,2,9],
 "group__rate__control.html#ga697e00462bcbc3165ed0f7bd25a88925":[12,2,0,2,0],
 "group__rate__control.html#ga6ae4ccee614dac82eb20d16c30d6cbe9":[12,2,0,2,7],
@@ -182,9 +214,8 @@ var NAVTREEINDEX3 =
 "group__rate__control.html#ga81e2619f5917dda2803f37c76080c3e5":[12,2,0,2,3],
 "group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e":[12,2,0,2,19],
 "group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5":[12,2,0,2,37],
+"group__rate__control.html#ga9f777728b7370404522efd914656761a":[12,2,0,2,29],
 "group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901":[12,2,0,2,16],
-"group__rate__control.html#gaa3c39a64e36dd054af783c40b6e387f2":[12,2,0,2,35],
-"group__rate__control.html#gaabc94f144903517a3d4aff8f65da1638":[12,2,0,2,29],
 "group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6":[12,2,0,2,34],
 "group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce":[12,2,0,2,22],
 "group__rate__control.html#gabfb0989110479fa704a1b245a4c4c1cf":[12,2,0,2,21],
@@ -197,6 +228,7 @@ var NAVTREEINDEX3 =
 "group__rate__control.html#gadfe05128d22bba397120763fe132c867":[12,2,0,2,6],
 "group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f":[12,2,0,2,18],
 "group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,14],
+"group__rate__control.html#gaf3b990f88a7036986750f9ae344129e9":[12,2,0,2,24],
 "group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,15],
 "group__speed__features.html":[12,2,0,0],
 "group__speed__features.html#ga375df45f353341a53823feb529182b2a":[12,2,0,0,0],
@@ -217,37 +249,5 @@ var NAVTREEINDEX3 =
 "group__tpl__modelling.html#gacb25270842c5ab92d1d90a211df955e5":[12,2,0,3,1],
 "group__transform__search.html":[12,2,4],
 "group__transform__search.html#ga4bdb6bc7b2510fc58a4e63212e811412":[12,2,4,1],
-"group__transform__search.html#ga6de2388a03e84841b43096d324e3ac26":[12,2,4,3],
-"group__transform__search.html#ga96f1b74712969cad39e8759642341ea3":[12,2,4,2],
-"group__transform__search.html#gaaad15ac6f5882d95c5daded8b167841c":[12,2,4,4],
-"group__transform__search.html#gab98eb8666e56c4f697af7e04e9ed8759":[12,2,4,5],
-"group__transform__search.html#gae30648a789cd8ef5cb98e0210db2371f":[12,2,4,0],
-"group__two__pass__algo.html":[12,2,0,4],
-"group__variance__partition.html":[12,2,11],
-"group__variance__partition.html#ga2a5965e60efd6f575542f55a48feb022":[12,2,11,0],
-"group__variance__partition.html#gae61ad7df0f818c5d89adfc8e139359df":[12,2,11,1],
-"index.html":[],
-"index.html#aom_sdk":[0],
-"index.html#av1_guide":[1],
-"index.html#main_intro":[0,0],
-"index.html#main_startpoints":[0,1],
-"index.html#main_support":[2],
-"intra__mode__search_8h.html":[14,0,2,2,8],
-"intra__mode__search_8h.html#a36fe8942d46efb604031987aef180df0":[14,0,2,2,8,7],
-"intra__mode__search_8h.html#a7577757a2046ae6b2234115b9aeddd5b":[14,0,2,2,8,10],
-"intra__mode__search_8h.html#aaf46284873fa449d7f843623a9e59c7f":[14,0,2,2,8,11],
-"intra__mode__search_8h.html#ac80bd25ae504f9dc621a5ced8a3e390f":[14,0,2,2,8,8],
-"intra__mode__search_8h.html#ade408273088bd18a20b290882c3d5da9":[14,0,2,2,8,9],
-"intra__mode__search_8h_source.html":[14,0,2,2,8],
-"intra__mode__search__utils_8h.html":[14,0,2,2,9],
-"intra__mode__search__utils_8h.html#a3f5fd5a4ab169294e490310fbc930617":[14,0,2,2,9,1],
-"intra__mode__search__utils_8h.html#ada17eb3ace47aa1bf1542bf81835c877":[14,0,2,2,9,0],
-"intra__mode__search__utils_8h_source.html":[14,0,2,2,9],
-"lookahead_8h.html":[14,0,2,2,10],
-"lookahead_8h.html#a057e2ff7a73b405643340cb1d5564653":[14,0,2,2,10,3],
-"lookahead_8h.html#a0ed9bea346e2febc22fd2e5c04f96ed2":[14,0,2,2,10,4],
-"lookahead_8h.html#a29315ad0754642cf92f547a36aa286b4":[14,0,2,2,10,0],
-"lookahead_8h.html#a36c0cd8514867cf37679891107355720":[14,0,2,2,10,5],
-"lookahead_8h.html#a442c559043280bd477c84f988af1c91f":[14,0,2,2,10,6],
-"lookahead_8h.html#a4539cc1e7762a3b379462873e9a3f97b":[14,0,2,2,10,2]
+"group__transform__search.html#ga6de2388a03e84841b43096d324e3ac26":[12,2,4,3]
 };
